@@ -1,6 +1,6 @@
 //! A collection of reusable algorithms without dependencies on any other module in the project.
 
-pub mod dbscan;
+pub mod clustering;
 pub mod gsom;
 pub mod mdp;
 pub mod nsga2;
