@@ -3,6 +3,7 @@
 use crate::algorithms::nsga2::Objective;
 use crate::construction::constraints::ConstraintModule;
 use crate::construction::heuristics::InsertionContext;
+use std::sync::Arc;
 
 mod costs;
 pub use self::costs::*;
@@ -14,7 +15,7 @@ mod fleet;
 pub use self::fleet::*;
 
 /// An actual objective on solution type.
-pub type TargetObjective = Box<dyn Objective<Solution = InsertionContext> + Send + Sync>;
+pub type TargetObjective = Arc<dyn Objective<Solution = InsertionContext> + Send + Sync>;
 
 /// An actual constraint.
-pub type TargetConstraint = Box<dyn ConstraintModule + Send + Sync>;
+pub type TargetConstraint = Arc<dyn ConstraintModule + Send + Sync>;
