@@ -1,9 +1,33 @@
-use crate::models::common::{Duration, Location, Schedule, TimeWindow};
+use crate::models::common::{Distance, Duration, Location, Schedule, TimeWindow};
 use crate::models::problem::{Actor, Job, Multi, Single};
 use crate::models::solution::Tour;
-use crate::utils::compare_shared;
+use crate::utils::{compare_floats, compare_shared};
+use std::cmp::Ordering;
 use std::sync::Arc;
 
+/// Specifies an extra commute information to reach the actual place.
+#[derive(Clone)]
+pub struct Commute {
+    /// An commute information to reach place from other location.
+    pub forward: CommuteInfo,
+
+    /// An commute information to get out from the place to the next location.
+    pub backward: CommuteInfo,
+}
+
+/// Commute information.
+#[derive(Clone)]
+pub struct CommuteInfo {
+    /// A previous or next location.
+    pub location: Location,
+
+    /// Travelled distance.
+    pub distance: Distance,
+
+    /// Travelled duration.
+    pub duration: Duration,
+}
+
 /// Specifies activity place.
 #[derive(Clone, Debug)]
 pub struct Place {
@@ -22,12 +46,15 @@ pub struct Activity {
     /// Specifies activity details.
     pub place: Place,
 
-    /// Specifies activity's schedule: actual arrival and departure time.
+    /// Specifies activity's schedule including commute time.
     pub schedule: Schedule,
 
-    /// Specifies job relation. Empty if it has no relation to single job (e.g. tour start or end).
-    /// If single job is part of multi job, then original job can be received via its dimens.
+    /// Specifies associated job. Empty if it has no association with a single job (e.g. tour start or end).
+    /// If single job is part of multi job, then original job can be received via `retrieve_job` method.
     pub job: Option<Arc<Single>>,
+
+    /// An extra commute time to the place.
+    pub commute: Option<Commute>,
 }
 
 /// Represents a tour performing jobs.
@@ -53,6 +80,7 @@ impl Activity {
             place: Place { location: 0, duration: 0.0, time: TimeWindow { start: 0.0, end: f64::MAX } },
             schedule: Schedule { arrival: 0.0, departure: 0.0 },
             job: Some(job),
+            commute: None,
         }
     }
 
@@ -66,6 +94,7 @@ impl Activity {
             },
             schedule: self.schedule.clone(),
             job: self.job.clone(),
+            commute: self.commute.clone(),
         }
     }
 
@@ -89,3 +118,40 @@ impl Activity {
         }
     }
 }
+
+impl Default for Commute {
+    fn default() -> Self {
+        Self { forward: CommuteInfo::default(), backward: CommuteInfo::default() }
+    }
+}
+
+impl Commute {
+    /// Checks whether there is no distance costs for commute.
+    pub fn is_zero_distance(&self) -> bool {
+        self.forward.is_zero_distance() & self.backward.is_zero_distance()
+    }
+
+    /// Gets total commute duration.
+    pub fn duration(&self) -> Duration {
+        self.forward.duration + self.backward.duration
+    }
+}
+
+impl Default for CommuteInfo {
+    fn default() -> Self {
+        Self { location: 0, distance: 0., duration: 0. }
+    }
+}
+
+impl CommuteInfo {
+    /// Checks whether there is no distance costs for part of commute.
+    pub fn is_zero_distance(&self) -> bool {
+        let is_zero_distance = compare_floats(self.distance, 0.) == Ordering::Equal;
+
+        if is_zero_distance && compare_floats(self.duration, 0.) != Ordering::Equal {
+            unreachable!("expected to have duration to be zero, got: {}", self.duration);
+        }
+
+        is_zero_distance
+    }
+}
