@@ -59,7 +59,7 @@ impl Tour {
 
     /// Inserts activity within its job to the end of tour.
     pub fn insert_last(&mut self, activity: Activity) -> &mut Tour {
-        self.insert_at(activity, self.activity_count() + 1);
+        self.insert_at(activity, self.job_activity_count() + 1);
         self
     }
 
@@ -167,8 +167,8 @@ impl Tour {
         !self.jobs.is_empty()
     }
 
-    /// Returns amount of job activities.
-    pub fn activity_count(&self) -> usize {
+    /// Returns total amount of job activities.
+    pub fn job_activity_count(&self) -> usize {
         if self.activities.is_empty() {
             0
         } else {
@@ -205,6 +205,7 @@ fn create_start_activity(actor: &Actor) -> Activity {
         schedule: Schedule { arrival: time.start, departure: time.start },
         place: Place { location: start.location, duration: 0.0, time },
         job: None,
+        commute: None,
     }
 }
 
@@ -216,6 +217,7 @@ fn create_end_activity(actor: &Actor) -> Option<Activity> {
             schedule: Schedule { arrival: time.start, departure: time.start },
             place: Place { location: place.location, duration: 0.0, time },
             job: None,
+            commute: None,
         }
     })
 }
