@@ -101,11 +101,15 @@ pub fn get_customer_ids_from_routes_sorted(insertion_ctx: &InsertionContext) ->
 }
 
 pub fn get_sorted_customer_ids_from_jobs(jobs: &[Job]) -> Vec<String> {
-    let mut ids = jobs.iter().map(|job| get_customer_id(&job)).collect::<Vec<String>>();
+    let mut ids = get_customer_ids_from_jobs(jobs);
     ids.sort();
     ids
 }
 
+pub fn get_customer_ids_from_jobs(jobs: &[Job]) -> Vec<String> {
+    jobs.iter().map(|job| get_customer_id(&job)).collect()
+}
+
 pub fn get_customer_ids_from_routes(insertion_ctx: &InsertionContext) -> Vec<Vec<String>> {
     insertion_ctx
         .solution
@@ -123,6 +127,14 @@ pub fn get_customer_ids_from_routes(insertion_ctx: &InsertionContext) -> Vec<Vec
         .collect()
 }
 
+pub fn get_customer_ids_from_unassigned(insertion_ctx: &InsertionContext) -> Vec<String> {
+    let mut job_ids = insertion_ctx.solution.unassigned.iter().map(|(job, _)| get_customer_id(job)).collect::<Vec<_>>();
+
+    job_ids.sort();
+
+    job_ids
+}
+
 pub fn get_customer_id(job: &Job) -> String {
     job.dimens().get_id().unwrap().clone()
 }
